
.. _developer_guide:

===============
Developer Guide
===============

Welcome to sktime's developer guide!

.. note::

    The developer guide is under development. We welcome contributions! For
    more details, please go to :issue:`464`.

sktime follows `scikit-learn <https://scikit-learn.org/stable/>`_\ ’s API whenever possible.
If you’re new to scikit-learn, take a look at their `getting-started guide <https://scikit-learn.org/stable/getting_started.html>`_.
If you’re already familiar with scikit-learn, you may still learn something new from their `developers’ guide <https://scikit-learn.org/stable/developers/index.html>`_.

.. toctree::
   :maxdepth: 1

   developer_guide/add_dataset
   developer_guide/add_estimators
   developer_guide/documentation
